Utility
=======

All modules below are used to supplement and extend the functionality of the main classes :doc:`includes/measurement` and :doc:`includes/sigfig`.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   parser
   typecheck
   chem/compound
   chem/element